@@ -33,7 +33,8 @@ cmaps_opts = tuple(sorted(['viridis', 'plasma', 'inferno', 'magma', 'cividis','b
 'terrain','brg', 'rainbow', 'jet'],key=lambda s: s.lower()))
 
 pth=realpath(__file__)
-example_files_decomp = [join(pth,d) for d in ['demo1.mat','demo2.mat','demo3.mat','demo4.mat']]
-example_files_raw = [join(pth,d) for d in ['raw1.mat','raw2.mat']]
+example_files_decomp = [join(pth,'anthem_datasets',d) for d in ['demo1.mat','demo2.mat','demo3.mat','demo4.mat']]
+example_files_raw = [join(pth,'anthem_datasets',d) for d in ['raw1.mat','raw2.mat']]
+example_cfg = [join(pth,'anthem_datasets',d) for d in ['demo1_cfg.p','demo2_cfg.p','demo3_cfg.p','demo4_cfg.p']]
 
 
